==> ejc-proequipmentcorp-impl-3.0.0-20230223.025151-333-sources.jar: com/ejianc/business/proequipmentcorpout/proxy/bean/ProxyContractDetailEntity.java <==
package com.ejianc.business.proequipmentcorpout.proxy.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备公司租出线-委托书明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_proxy_contract_detail")
public class ProxyContractDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="proxy_id")
    private Long proxyId; // 委托书主键
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计租单位
    @TableField(value="unit_name")
    private String unitName; // 计租单位
    @TableField(value="proxy_num")
    private BigDecimal proxyNum; // 委托数量
    @TableField(value="plan_use_time")
    private Date planUseTime; // 预计使用时间
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="unit_m_id")
    private Long unitMId; // 计量单位id
    @TableField(value="unit_m_name")
    private String unitMName; // 计量单位
    @TableField(value="source_id")
    private Long sourceId; // 来源Id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细Id
    
    
    

    public Long getProxyId() {
        return proxyId;
    }

    public void setProxyId(Long proxyId) {
        this.proxyId = proxyId;
    }
    public Long getequipmentTypeId() {
        return equipmentTypeId;
    }

    public void setequipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getequipmentTypeName() {
        return equipmentTypeName;
    }

    public void setequipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getequipmentId() {
        return equipmentId;
    }

    public void setequipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getequipmentName() {
        return equipmentName;
    }

    public void setequipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getequipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setequipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getequipmentCode() {
        return equipmentCode;
    }

    public void setequipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getProxyNum() {
        return proxyNum;
    }

    public void setProxyNum(BigDecimal proxyNum) {
        this.proxyNum = proxyNum;
    }
    public Date getPlanUseTime() {
        return planUseTime;
    }

    public void setPlanUseTime(Date planUseTime) {
        this.planUseTime = planUseTime;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }
    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}

==> ejc-proequipmentcorp-impl-3.0.0-20251013.062057-516-sources.jar: com/ejianc/business/proequipmentcorpout/proxy/bean/ProxyContractDetailEntity.java <==
package com.ejianc.business.proequipmentcorpout.proxy.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 设备公司租出线-委托书明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_outequipmentcorp_proxy_contract_detail")
public class ProxyContractDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="proxy_id")
    private Long proxyId; // 委托书主键
    @TableField(value="equipment_type_id")
    private Long equipmentTypeId; // 设备分类id
    @TableField(value="equipment_type_name")
    private String equipmentTypeName; // 设备分类名称
    @TableField(value="equipment_id")
    private Long equipmentId; // 设备id
    @TableField(value="equipment_name")
    private String equipmentName; // 设备名称
    @TableField(value="equipment_type_code")
    private String equipmentTypeCode; // 设备分类编码
    @TableField(value="equipment_code")
    private String equipmentCode; // 设备编码
    @TableField(value="spec")
    private String spec; // 规格型号
    @TableField(value="unit_id")
    private Long unitId; // 计租单位
    @TableField(value="unit_name")
    private String unitName; // 计租单位
    @TableField(value="proxy_num")
    private BigDecimal proxyNum; // 委托数量
    @TableField(value="plan_use_time")
    private Date planUseTime; // 预计使用时间
    @TableField(value="memo")
    private String memo; // 备注
    @TableField(value="unit_m_id")
    private Long unitMId; // 计量单位id
    @TableField(value="unit_m_name")
    private String unitMName; // 计量单位
    @TableField(value="source_id")
    private Long sourceId; // 来源Id
    @TableField(value="source_detail_id")
    private Long sourceDetailId; // 来源明细Id
    @TableField(value="detail_measurement_rules")
    private String detailMeasurementRules;//计量规则

    @TableField(value="job_content")
    private String jobContent;//工作内容

    public String getDetailMeasurementRules() {
        return detailMeasurementRules;
    }

    public void setDetailMeasurementRules(String detailMeasurementRules) {
        this.detailMeasurementRules = detailMeasurementRules;
    }

    public String getJobContent() {
        return jobContent;
    }

    public void setJobContent(String jobContent) {
        this.jobContent = jobContent;
    }
    
    

    public Long getProxyId() {
        return proxyId;
    }

    public void setProxyId(Long proxyId) {
        this.proxyId = proxyId;
    }
    public Long getequipmentTypeId() {
        return equipmentTypeId;
    }

    public void setequipmentTypeId(Long equipmentTypeId) {
        this.equipmentTypeId = equipmentTypeId;
    }
    public String getequipmentTypeName() {
        return equipmentTypeName;
    }

    public void setequipmentTypeName(String equipmentTypeName) {
        this.equipmentTypeName = equipmentTypeName;
    }
    public Long getequipmentId() {
        return equipmentId;
    }

    public void setequipmentId(Long equipmentId) {
        this.equipmentId = equipmentId;
    }
    public String getequipmentName() {
        return equipmentName;
    }

    public void setequipmentName(String equipmentName) {
        this.equipmentName = equipmentName;
    }
    public String getequipmentTypeCode() {
        return equipmentTypeCode;
    }

    public void setequipmentTypeCode(String equipmentTypeCode) {
        this.equipmentTypeCode = equipmentTypeCode;
    }
    public String getequipmentCode() {
        return equipmentCode;
    }

    public void setequipmentCode(String equipmentCode) {
        this.equipmentCode = equipmentCode;
    }
    public String getSpec() {
        return spec;
    }

    public void setSpec(String spec) {
        this.spec = spec;
    }
    public Long getUnitId() {
        return unitId;
    }

    public void setUnitId(Long unitId) {
        this.unitId = unitId;
    }
    public String getUnitName() {
        return unitName;
    }

    public void setUnitName(String unitName) {
        this.unitName = unitName;
    }
    public BigDecimal getProxyNum() {
        return proxyNum;
    }

    public void setProxyNum(BigDecimal proxyNum) {
        this.proxyNum = proxyNum;
    }
    public Date getPlanUseTime() {
        return planUseTime;
    }

    public void setPlanUseTime(Date planUseTime) {
        this.planUseTime = planUseTime;
    }
    public String getMemo() {
        return memo;
    }

    public void setMemo(String memo) {
        this.memo = memo;
    }
    public Long getUnitMId() {
        return unitMId;
    }

    public void setUnitMId(Long unitMId) {
        this.unitMId = unitMId;
    }
    public String getUnitMName() {
        return unitMName;
    }

    public void setUnitMName(String unitMName) {
        this.unitMName = unitMName;
    }
    public Long getSourceId() {
        return sourceId;
    }

    public void setSourceId(Long sourceId) {
        this.sourceId = sourceId;
    }
    public Long getSourceDetailId() {
        return sourceDetailId;
    }

    public void setSourceDetailId(Long sourceDetailId) {
        this.sourceDetailId = sourceDetailId;
    }
    
}
